@@ -55,6 +55,8 @@
 #'
 #' @seealso [dRiftDM::component_shelf()], [dRiftDM::drift_dm()]
 #'
+#' @references
+#' \insertRef{Ratcliff1978}{dRiftDM}
 #' @export
 ratcliff_dm <- function(var_non_dec = FALSE, var_start = FALSE,
                         var_drift = FALSE, instr = NULL, obs_data = NULL,
@@ -386,7 +388,15 @@ nt_uniform <- function(prms_model, prms_solve, t_vec, one_cond, ddm_opts) {
 #'
 #'
 #' Per default the shape parameter `a` is set to 2 and not allowed to
-#' vary. The model assumes the amplitude `A` to be negative for
+#' vary. This is because the derivative of the scaled gamma-distribution
+#' function does not exist at `t = 0` for `a < 2`. We generally recommend keeping
+#' `a` fixed to 2 for several reasons. If users decide to set `a != 2`, then a
+#' small value of `0.0005` is added to the time vector `t_vec` before calculating
+#' the derivative of the scaled gamma-distribution as originally introduced by
+#' \insertCite{Ulrichetal.2015;textual}{dRiftDM}. This can lead to large
+#' numerical inaccuracies if `tau` is small and/or `dt` is large.
+#'
+#' The model assumes the amplitude `A` to be negative for
 #' incompatible trials. Also, the model contains the custom parameter
 #' `peak_l`, containing the peak latency (`(a-2)*tau`).
 #'
@@ -627,7 +637,7 @@ nt_truncated_normal <- function(prms_model, prms_solve, t_vec, one_cond,
   if (!is.numeric(t_vec) | length(t_vec) <= 1) {
     stop("t_vec is not a vector")
   }
-  if (sd_non_dec <= dt) {
+  if (sd_non_dec < dt) {
     stop("sd_non_dec should not be smaller than dt!")
   }
 
@@ -1018,7 +1028,7 @@ dt_b_weibull <- function(prms_model, prms_solve, t_vec, one_cond, ddm_opts) {
 #' `mu_int_fun` but which throws an error. Might come in handy when a user
 #' doesn't require the integral of the drift rate.
 #'
-#' See \code{vignette("use_ddm_models", "dRiftDM")} for more information on how
+#' See \code{vignette("customize_ddms", "dRiftDM")} for more information on how
 #' to set/modify/customize the components of a diffusion model.
 #'
 #' @returns
