@@ -14,7 +14,7 @@ plot_one_traces <- function(traces_obj, col, col_b, xlab, ylab, xlim,
   }
 
   # Plot each condition's traces
-  e_samples <- unpack_traces(traces_obj)
+  e_samples <- unpack_obj(traces_obj)
   t_vec <- attr(traces_obj, "t_vec")
 
   for (i in 1:nrow(e_samples)) {
@@ -727,7 +727,7 @@ plot.delta_funs <- function(x, ..., dv = NULL, col = NULL, xlim = NULL,
 #' for flexible arrangement of multiple plots on a single graphics device.
 #'
 #'
-#' @param x an object of type `list_stats_dm`, which is essentially a list
+#' @param x an object of type `stats_dm_list`, which is essentially a list
 #'  multiple statistics, resulting from a call to [dRiftDM::calc_stats()].
 #' @param mfrow an optional numeric vector of length 2, specifying the number of
 #'  rows and columns for arranging multiple panels in a single plot
@@ -737,10 +737,14 @@ plot.delta_funs <- function(x, ..., dv = NULL, col = NULL, xlim = NULL,
 #'  individual `stats_dm` object in `x`.
 #'
 #' @details
-#' The `plot.list_stats_dm()` function is "merely" a wrapper. All plotting
-#' is done by the respective `plot()` methods. When users want more control
-#' over each plot, it is best to call the `plot()` function separately for
-#' each statistic in the list (e.g., `plot(x$cafs)`; `plot(x$quantiles)`)
+#' The `plot.stats_dm_list()` function is "merely" a wrapper. All plotting
+#' is done by the respective `plot()` methods. If `dRiftDM` doesn't provide a
+#' `plot()` method for an object stored in `x`, the respective entry is
+#' skipped and a message is displayed.
+#'
+#' When users want more control over each plot, it is best to call the
+#' `plot()` function separately for each statistic in the list
+#' (e.g., `plot(x$cafs)`; `plot(x$quantiles)`)
 #'
 #'
 #' @returns
@@ -758,13 +762,22 @@ plot.delta_funs <- function(x, ..., dv = NULL, col = NULL, xlim = NULL,
 #' [dRiftDM::plot.delta_funs()], [dRiftDM::calc_stats()]
 #'
 #' @export
-plot.list_stats_dm <- function(x, ..., mfrow = NULL) {
+plot.stats_dm_list <- function(x, ..., mfrow = NULL) {
   if (!is.null(mfrow)) {
     withr::local_par(mfrow = mfrow)
   }
 
-  for (one_stats_obj in x) {
-    plot(one_stats_obj, ...)
+
+  for (obj in x) {
+    class_obj <- class(obj)[1]
+    if (!(class_obj %in% c("cafs", "quantiles", "delta_funs"))) {
+      message(
+        "dRiftDM doesn't provide a plot method for objects of type ",
+        class_obj, ", skipping this entry."
+      )
+      next
+    }
+    plot(obj, ...)
   }
   invisible()
 }
@@ -905,6 +918,9 @@ hist.coefs_dm <- function(x, ..., separate_plots = TRUE, alpha = 0.5,
 #' conditions.
 #' @param legend_pos character, specifying the position of the legend on the
 #' plot (e.g., `"topright"`).
+#' @param mfrow an optional numeric vector of length 2, specifying the number of
+#'  rows and columns for arranging multiple panels in a single plot. If `NULL`
+#'  (default), `mfrow` will be `c(3,2)`.
 #' @param ... additional arguments passed forward.
 #'
 #' @details
@@ -921,7 +937,7 @@ hist.coefs_dm <- function(x, ..., separate_plots = TRUE, alpha = 0.5,
 #' plotted using different colors as specified in `color`.
 #'
 #' When the evaluation of a model component fails, the respective component
-#' will not be plotted, but no warning is ushered.
+#' will not be plotted, but no warning is thrown.
 #'
 #' @returns
 #' Nothing (`NULL`; invisibly)
@@ -939,7 +955,8 @@ hist.coefs_dm <- function(x, ..., separate_plots = TRUE, alpha = 0.5,
 #'
 #' @export
 plot.drift_dm <- function(x, ..., conds = NULL, col = NULL, xlim = NULL,
-                          legend = NULL, legend_pos = "topright") {
+                          legend = NULL, legend_pos = "topright",
+                          mfrow = NULL) {
   drift_dm_obj <- x
 
 
@@ -1006,7 +1023,10 @@ plot.drift_dm <- function(x, ..., conds = NULL, col = NULL, xlim = NULL,
 
 
   # plot everything
-  withr::local_par(mfrow = c(3, 2))
+  if (is.null(mfrow)) {
+    mfrow <- c(3, 2)
+  }
+  withr::local_par(mfrow = mfrow)
   # get the relevant time steps (for y-axis scaling)
   select_indices_t <- which(t_vec >= xlim[1] & t_vec <= xlim[2])
 
@@ -1134,7 +1154,7 @@ plot.drift_dm <- function(x, ..., conds = NULL, col = NULL, xlim = NULL,
 #'
 #' @return A character vector of colors, matching the length of `unique_conds`.
 #'
-#' @keywords intern
+#' @keywords internal
 set_default_colors <- function(colors, unique_conds, default_colors) {
   if (is.null(colors)) {
     colors <- default_colors
