@@ -1,26 +1,26 @@
 test_that("print.drift_dm_fits works as expected", {
-  dm_fits_ids <- load_fits_ids(
-    path = test_path("fixtures", "dm_fits_ids"),
+  drift_dm_fits <- load_fits_ids(
+    path = test_path("fixtures", "drift_dm_fits"),
     detailed_info = F,
     fit_procedure_name = "test_case_saved", check_data = F
   )
 
   # standard print
   expect_snapshot(
-    print(dm_fits_ids)
+    print(drift_dm_fits)
   )
 })
 
 
 test_that("summary.drift_dm_fits and print", {
-  dm_fits_ids <- load_fits_ids(
-    path = test_path("fixtures", "dm_fits_ids"),
+  drift_dm_fits <- load_fits_ids(
+    path = test_path("fixtures", "drift_dm_fits"),
     detailed_info = F,
     fit_procedure_name = "test_case_saved", check_data = F
   )
 
   # results from summary -> data frame of parameters
-  sum_obj <- summary(dm_fits_ids)
+  sum_obj <- summary(drift_dm_fits)
 
 
   expect_identical(
@@ -41,19 +41,19 @@ test_that("summary.drift_dm_fits and print", {
     c(muc = 5, b = 0.8, non_dec = 0.5)
   )
 
-  prms <- coef(dm_fits_ids, select_unique = F)
+  prms <- coef(drift_dm_fits, select_unique = F)
   expect_identical(sum_obj$prms, prms)
 
   expect_identical(sum_obj$N, 2L)
 
   # one stats
   m_b <- mean(sapply(
-    dm_fits_ids$all_fits,
+    drift_dm_fits$all_fits,
     \(x) x$flex_prms_obj$prms_matrix[1, "b"]
   ))
 
   err_b <- sd(sapply(
-    dm_fits_ids$all_fits,
+    drift_dm_fits$all_fits,
     \(x) x$flex_prms_obj$prms_matrix[1, "b"]
   )) / sqrt(2)
 
